@@ -43,7 +43,7 @@ except ImportError:
             return self
 
         def __call__(self, *args, **kwargs):
-            raise RuntimeError('rqdatac is required')
+            raise RuntimeError(_('rqdatac is not available, extension apis will not function properly'))
 
 
     rqdatac = DummyRQDatac()
@@ -178,7 +178,7 @@ def index_weights(order_book_id, date=None):
     """
     env = Environment.get_instance()
     data_proxy = env.data_proxy
-    dt = data_proxy.get_previous_trading_date(env.trading_dt.date())
+    dt = to_date(data_proxy.get_previous_trading_date(env.trading_dt.date()))
     if date is None:
         date = dt
     else:
