@@ -1,4 +1,4 @@
-from rqalpha.api import *
+from rqalpha.apis import *
 
 import talib
 
@@ -15,7 +15,6 @@ def init(context):
 # 你选择的证券的数据更新将会触发此段逻辑，例如日或分钟历史数据切片或者是实时数据切片更新
 def handle_bar(context, bar_dict):
     # 开始编写你的主要的算法逻辑
-
     # bar_dict[order_book_id] 可以拿到某个证券的bar信息
     # context.portfolio 可以拿到现在的投资组合状态信息
 
@@ -34,7 +33,7 @@ def handle_bar(context, bar_dict):
     plot("long avg", long_avg[-1])
 
     # 计算现在portfolio中股票的仓位
-    cur_position = context.portfolio.positions[context.s1].quantity
+    cur_position = get_position(context.s1).quantity
     # 计算现在portfolio中的现金可以购买多少股票
     shares = context.portfolio.cash / bar_dict[context.s1].close
 
