@@ -15,7 +15,7 @@
 #         在此前提下，对本软件的使用同样需要遵守 Apache 2.0 许可，Apache 2.0 许可与本许可冲突之处，以本许可为准。
 #         详细的授权流程，请联系 public@ricequant.com 获取。
 
-from functools import lru_cache
+from rqalpha.utils.functools import lru_cache
 
 import six
 import numpy as np
@@ -303,7 +303,7 @@ class BarObject(object):
 
         if isinstance(self._data, dict):
             # in pt
-            base.extend((k, v) for k, v in six.iteritems(self._data) if k != 'datetime')
+            base.extend((k, v) for k, v in self._data.items() if k != 'datetime')
         else:
             base.extend((n, self._data[n]) for n in self._data.dtype.names if n != 'datetime')
         return "Bar({0})".format(', '.join('{0}: {1}'.format(k, v) for k, v in base))
